@charset "UTF-8";

/************
 * Tooltips *
 ************/

tooltip {
	&.background {
		// background-color needs to be set this way otherwise it gets drawn twice
		// see https://bugzilla.gnome.org/show_bug.cgi?id=736155 for details.
		background-color: gtk("@tooltip_background");
		background-clip: padding-box;
	}

	color: gtk("@tooltip_text");
	padding: 4px; /* not working */
	border-radius: $r;
	box-shadow: none; // otherwise it gets inherited by windowframe.csd
	text-shadow: none;
	border: 1px solid gtk("@tooltip_border");
	&.window-frame.csd {
		background-color: transparent;
		box-shadow: none;
	}
	decoration {
		background-color: transparent;
	}
}

tooltip * {
	//Yeah this is ugly
	padding: 0px;
	background-color: transparent;
	color: gtk("@tooltip_text"); // just to be sure
}
