#MozillaGtkWidget {
	scrollbar {
		padding: 0px;
		slider {
			margin: 0px;
			background: none;
			background-color: gtkalpha(gtk("@theme_fg_color"), 0.5);

			&:hover {
				background-color: gtkalpha( gtk("@theme_button_decoration_hover"), 0.5);
			}
			&:focus {
				background-color: gtkalpha( gtk("@theme_button_decoration_focus"), 0.5);
			}
		}
	}
}
