@charset "UTF-8";

/*********
 * Menus *
 *********/

accelerator {
	opacity: 0.5;
	margin-left: 2.5mm;
}

menubar,
.menubar {
	padding: 0px;
	box-shadow: none;
	border-style: none;
	background-color: gtk("@theme_header_background");

	&:backdrop {
		background-color: gtk("@theme_header_background_backdrop");
	}

	> item {
		min-height: 4.5mm;
		padding: 1.25mm 2.5mm;
		@if $new-highlight {
			border-bottom: 3px solid transparent;
		}

		&:hover {
			//Seems like it :hover even with keyboard focus
			@if $new-highlight {
				background-color: gtkalpha(
					gtk("@theme_button_decoration_focus"),
					0.3
				);
				color: gtk("@theme_button_foreground_active");
				border-bottom: 3px
					solid
					gtk("@theme_button_decoration_focus");
			} @else {
				background-color: gtk(
					"@theme_button_decoration_focus"
				);
				color: gtk("@theme_button_foreground_active");
			}
		}

		&:disabled {
			color: gtk("@insensitive_fg_color");
			box-shadow: none;

			&:backdrop {
				background-color: gtk("@theme_unfocused_bg_color");
				color: gtk("@insensitive_unfocused_fg_color");
			}
		}

		&:backdrop {
			background-color: gtk("@theme_unfocused_bg_color");
			color: gtk("@theme_unfocused_fg_color");
		}
	}
}

popover, popover.background {
	background-color: transparent;

	contents, > arrow {
		padding: 4px; // Use px to avoid overflow when using fractional scaling
		background-color: gtkmix(gtk("@theme_bg_color"), gtk("@theme_base_color"), 0.3);
		border: 1px solid gtk("@borders");
		border-radius: $r;
	}

	// axes borders in a composited env
	separator {
		color: gtk("@borders");
		margin: 0.75mm 0;
	}

	modelbutton {
		text-shadow: none;
		min-height: 4.5mm;
		min-width: 10mm;
		padding: 0.75mm 2mm;
		border: 1px solid transparent;

		@if $new-highlight {
			border: 1px solid transparent;
			margin: 1mm;
		}

		accelerator {
			color: gtkalpha(currentColor, 0.55);
		}
		check,
		radio {
			&:dir(ltr) {
				margin-right: 1.5mm;
			}
			&:dir(rtl) {
				margin-left: 1.5mm;
			}
		}

		arrow.left {
			-gtk-icon-source: -gtk-icontheme($arrow_left);
		}

		arrow.right {
			-gtk-icon-source: -gtk-icontheme($arrow_right);
		}

		&:hover {
			background-color: gtkalpha(gtk("@theme_selected_bg_color"), 0.3);
			border: 1px solid gtk("@theme_button_decoration_focus"); // Use px to avoid strange thickness when fractional scaling is used
			border-radius: $r;
		}

		&:disabled {
			color: gtk("@insensitive_fg_color");

			&:backdrop {
				color: gtk("@insensitive_unfocused_fg_color");
			}
		}

		&:backdrop,
		&:backdrop:hover {
			color: gtk("@theme_unfocused_fg_color");
			background-color: gtk("@theme_unfocused_bg_color");
		}
	}
}

GtkVolumeButton.button {
	padding: 1.25mm;
}
